@@ -1,37 +1,43 @@
 ## CLI to generate CLIs
+from typing import TextIO
+
 import rich_click as click
 from rich.console import Console
 from rich.syntax import Syntax
 
+from .helper import print_rich_table, write_to_file
+from .homer import Homer
+from .loader import Loader
 from .manifests import get_cli_manifest
-from .transformer import Transformer, write_to_file
+from .transformer import Transformer
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
 @click.version_option()
-def cli():
+def cli() -> None:
     pass
 
 
 @cli.command()
 @click.argument('manifests', type=click.File('rb'), nargs=-1)
-def load(manifests):
+def load(manifests: list[TextIO]) -> None:
     """Load CLI for given manifest(s)"""
     for manifest in manifests:
-        cli = Transformer(manifest).load_cli()
-        click.secho(f"~ Generated {cli.name} CLI v{cli.version} ~", fg="green")
+        T = Transformer(manifest)
+        Loader.load_cli(T.cli)
+        Homer.save_cli_metadata(manifest.name, T.cli)
+        click.secho(f"~ Generated {T.cli.name} CLI v{T.cli.version} ~", fg="green")
         click.secho(click.style("$", fg="magenta"), nl=False)
-        click.echo(f" {cli.name} -h")
+        click.echo(f" {T.cli.name} -h")
 
 
 @cli.command()
 @click.argument('manifest', type=click.File('rb'))
-def render(manifest):
+def render(manifest: TextIO) -> None:
     """Render the CLI manifest generation as code"""
     T = Transformer(manifest)
-    T.render_cli()
     syntax = Syntax(T.cli.code, "python", theme="monokai", line_numbers=False)
     console = Console()
     console.print(syntax)
@@ -39,7 +45,7 @@ def render(manifest):
 
 
 @cli.command()
-@click.argument('cli_name', type=str)
+@click.argument('cli_name', type=str, default="cliffy")
 @click.option('--version', '-v', type=str, show_default=True, default="v1", help="Manifest version")
 @click.option(
     '--render', type=bool, is_flag=True, show_default=True, default=False, help="Render template to terminal directly"
@@ -52,13 +58,10 @@ def render(manifest):
     default=False,
     help="Raw template without boilerplate helpers and examples.",
 )
-def init(cli_name, version, render, raw):
+def init(cli_name: str, version: str, render: bool, raw: bool) -> None:
     """Generate a CLI manifest template"""
     manifest = get_cli_manifest(version)
-    if raw:
-        template = manifest.get_raw_template(cli_name)
-    else:
-        template = manifest.get_template(cli_name)
+    template = manifest.get_raw_template(cli_name) if raw else manifest.get_template(cli_name)
 
     if render:
         syntax = Syntax(template, "yaml", theme="monokai", line_numbers=False)
@@ -68,24 +71,39 @@ def init(cli_name, version, render, raw):
         write_to_file(f'{cli_name}.yaml', text=template)
 
 
-@cli.command()
-@click.argument('cli_name', type=str)
-def enable(cli_name):
-    click.echo("# TODO")
-
-
-@cli.command()
-@click.argument('cli_name', type=str)
-def disable(cli_name):
-    click.echo("# TODO")
-
-
 @cli.command("list")
-def list_clis():
+def list_clis() -> None:
+    "List of CLIs loaded"
+    metadata_paths = Homer.get_cli_metadata_paths()
+    cols = ["Name", "Version", "Manifest"]
+    rows = []
+    for path in metadata_paths:
+        runnerpath, metadata = Homer.get_cli_metadata(path)
+        rows.append([path.name, metadata.get("version", "error"), runnerpath])
+
+    print_rich_table(cols, rows, styles=["cyan", "magenta", "green"])
+
+
+@cli.command()
+@click.argument('cli_names', type=str, nargs=-1)
+def unload(cli_names: list[str]) -> None:
+    "Remove a loaded CLI by name"
+    for cli_name in cli_names:
+        if Homer.is_cliffy_cli(cli_name):
+            Homer.remove_cli_metadata(cli_name)
+            Loader.unload_cli(cli_name)
+            click.secho(f"~ {cli_name} unloaded", fg="green")
+        else:
+            click.secho(f"~ {cli_name} not found", fg="red")
+
+
+@cli.command()
+@click.argument('cli_name', type=str)
+def enable(cli_name) -> None:
     click.echo("# TODO")
 
 
 @cli.command()
 @click.argument('cli_name', type=str)
-def unload(cli_name):
+def disable(cli_name) -> None:
     click.echo("# TODO")
